from distutils.core import setup
from distutils.command.install_data import install_data
from distutils.dep_util import newer
from distutils.log import info
from glob import glob
import os
import sys
import string

class InstallData(install_data):
  def run (self):
    self.data_files.extend (self._compile_po_files ())
    install_data.run (self)

  def _compile_po_files (self):
    data_files = []
    PO_DIR = 'po'
    lang = os.environ.get('LANG', None)
    lang = lang.split('.')[0]
    tmp = lang.split('_')
    if tmp[0] == string.lower(tmp[1]):
      lang = tmp[0]
    if lang:
      po = os.path.join(PO_DIR, '%s.po' % lang)
      mo = os.path.join('build', 'mo', lang, 'cometsound.mo')

      directory = os.path.dirname(mo)
      if not os.path.exists(directory):
        info('creating %s' % directory)
        os.makedirs(directory)

      if newer(po, mo):
        # True if mo doesn't exist
        cmd = 'msgfmt -o %s %s' % (mo, po)
        info('compiling %s -> %s' % (po, mo))
        if os.system(cmd) != 0:
          raise SystemExit('Error while running msgfmt')

      dest = os.path.dirname(os.path.join('share', 'locale-langpack', lang, 'LC_MESSAGES', 'cometsound.mo'))
      data_files.append((dest, [mo]))

    return data_files

files = ['data/*']

setup(name = "cometsound",
    version = "0.1.3",
    description = "Music player for GNU/Linux written in python, using pygtk and gstreamer libraries.",
    author = "Andrea Bernardini",
    author_email = "andrebask@gmail.com",
    url = "http://thelinuxroad.com/",
    packages = [''],
    package_dir = {'' : 'src'},
    package_data = {'': files},
    license='GPL v2',	
    data_files=[
	('bin/', ['cometsound']),
        ('share/applications', ['data/cometsound.desktop']),
        ('share/cometsound/src', ['data/icon.svg']),
    	('share/doc/cometsound', ['doc/copyright', 'doc/COPYING']),
    	('share/cometsound/src', glob('src/*.py'))
    ],
    long_description = """Music player for GNU/Linux written in python, using pygtk and gstreamer libraries.""", 
    cmdclass={'install_data': InstallData}	
) 
